@@ -1,7 +1,7 @@
 from .metrics import mr_score, mrr_score, hits_at_n_score, rank_score
-from .protocol import add_reverse, get_train_triplets_set, BaseEval, TrainEval_By_Triplet
+from .protocol import add_reverse, get_triplets_set, BaseEval, TrainEval_By_Triplet
 from .protocol import TrainEval_For_Trans
 
 __all__ = ['mr_score', 'mrr_score', 'hits_at_n_score', 'rank_score',
-           'add_reverse', 'get_train_triplets_set', 'BaseEval', 'TrainEval_By_Triplet',
+           'add_reverse', 'get_triplets_set', 'BaseEval', 'TrainEval_By_Triplet',
            'TrainEval_For_Trans']
